==> cscec5b-rmat-impl-3.0.1-20230508.085156-156-sources.jar: com/ejianc/business/rmat/bean/ExitEntity.java <==
package com.ejianc.business.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退场单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_exit")
public class ExitEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_source_id")
    private String projectSourceId; // 项目来源ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_source_id")
    private String orgSourceId; // 组织来源ID
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 上级组织
    @TableField(value="parent_org_source_id")
    private String parentOrgSourceId; // 上级组织来源ID
    @TableField(value="contract_id")
    private String contractId; // 合同主键
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="supplier_id")
    private Long supplierId; // 设备供应商
    @TableField(value="supplier_name")
    private String supplierName; // 供应商名称
    @TableField(value="supplier_source_id")
    private String supplierSourceId; // 供应商来源ID
    @TableField(value="exit_date")
    private Date exitDate; // 退场日期
    @TableField(value="confirm_date")
    private Date confirmDate; // 确认日期
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="confirm_flag")
    private Integer confirmFlag; // 确认状态0-未确认1-已确认2-已拒绝
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="confirmer_id")
    private Long confirmerId; // 确认人
    @TableField(value="confirmer_name")
    private String confirmerName; // 确认人名称
    @TableField(value="exit_note")
    private String exitNote; // 退场说明
    @TableField(value="confirm_note")
    private String confirmNote; // 确认说明
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="def1")
    private String def1; // 
    @TableField(value="def2")
    private String def2; // 
    @TableField(value="def3")
    private String def3; // 
    @TableField(value="def4")
    private String def4; // 
    @TableField(value="def5")
    private String def5; // 
    @TableField(value="apply_id")
    private Long applyId; // 申请单ID
    @TableField(value="save_state")
    private Integer saveState; // 保存状态（0-暂存态，1-保存态）
    @TableField(value="use_state")
    private Integer useState; // 推送NC状态，0-未推送，1-已推送
    @TableField(value="push_user_id")
    private Long pushUserId; // 推送人主键
    @TableField(value="push_user_source_id")
    private String pushUserSourceId; // 推送人来源ID
    @TableField(value="push_user_name")
    private String pushUserName; // 推送人名称
    @TableField(value="isaddrecord")
    private String isaddrecord; // 是否补录，0-否，1-是
    @TableField(value="addrcdreson")
    private String addrcdreson; // 补录原因
    @TableField(value="commit_id")
    private Long commitId; // 提交人
    @TableField(value="link_id")
    private Long linkId; // 联系人
    @TableField(value="link_name")
    private String linkName; // 联系人名称
    @TableField(value="link_telephone")
    private String linkTelephone; // 联系人电话
    @TableField(value="apply_date")
    private Date applyDate; // 申请日期
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="apply_code")
    private String applyCode;//申请单编号

    @TableField(exist=false)
    @SubEntity(serviceName="exitDetailService",pidName = "exitId")
    private List<ExitDetailEntity> exitDetail = new ArrayList<>(); // 退场单明细
    @TableField(exist=false)
    private List<ExitSupplierEntity> exitSupplierList = new ArrayList<>();//退场劳务队明细

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgSourceId() {
        return parentOrgSourceId;
    }

    public void setParentOrgSourceId(String parentOrgSourceId) {
        this.parentOrgSourceId = parentOrgSourceId;
    }
    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierSourceId() {
        return supplierSourceId;
    }

    public void setSupplierSourceId(String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }
    public Date getExitDate() {
        return exitDate;
    }

    public void setExitDate(Date exitDate) {
        this.exitDate = exitDate;
    }
    public Date getConfirmDate() {
        return confirmDate;
    }

    public void setConfirmDate(Date confirmDate) {
        this.confirmDate = confirmDate;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Integer getConfirmFlag() {
        return confirmFlag;
    }

    public void setConfirmFlag(Integer confirmFlag) {
        this.confirmFlag = confirmFlag;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getConfirmerId() {
        return confirmerId;
    }

    public void setConfirmerId(Long confirmerId) {
        this.confirmerId = confirmerId;
    }
    public String getConfirmerName() {
        return confirmerName;
    }

    public void setConfirmerName(String confirmerName) {
        this.confirmerName = confirmerName;
    }
    public String getExitNote() {
        return exitNote;
    }

    public void setExitNote(String exitNote) {
        this.exitNote = exitNote;
    }
    public String getConfirmNote() {
        return confirmNote;
    }

    public void setConfirmNote(String confirmNote) {
        this.confirmNote = confirmNote;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }
    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }
    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }
    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }
    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }
    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public Integer getSaveState() {
        return saveState;
    }

    public void setSaveState(Integer saveState) {
        this.saveState = saveState;
    }
    public Integer getUseState() {
        return useState;
    }

    public void setUseState(Integer useState) {
        this.useState = useState;
    }
    public Long getPushUserId() {
        return pushUserId;
    }

    public void setPushUserId(Long pushUserId) {
        this.pushUserId = pushUserId;
    }
    public String getPushUserSourceId() {
        return pushUserSourceId;
    }

    public void setPushUserSourceId(String pushUserSourceId) {
        this.pushUserSourceId = pushUserSourceId;
    }
    public String getPushUserName() {
        return pushUserName;
    }

    public void setPushUserName(String pushUserName) {
        this.pushUserName = pushUserName;
    }
    public String getIsaddrecord() {
        return isaddrecord;
    }

    public void setIsaddrecord(String isaddrecord) {
        this.isaddrecord = isaddrecord;
    }
    public String getAddrcdreson() {
        return addrcdreson;
    }

    public void setAddrcdreson(String addrcdreson) {
        this.addrcdreson = addrcdreson;
    }
    public Long getCommitId() {
        return commitId;
    }

    public void setCommitId(Long commitId) {
        this.commitId = commitId;
    }
    public Long getLinkId() {
        return linkId;
    }

    public void setLinkId(Long linkId) {
        this.linkId = linkId;
    }
    public String getLinkName() {
        return linkName;
    }

    public void setLinkName(String linkName) {
        this.linkName = linkName;
    }
    public String getLinkTelephone() {
        return linkTelephone;
    }

    public void setLinkTelephone(String linkTelephone) {
        this.linkTelephone = linkTelephone;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }

    public List<ExitDetailEntity> getExitDetail() {
        return exitDetail;
    }

    public void setExitDetail(List<ExitDetailEntity> exitDetail) {
        this.exitDetail = exitDetail;
    }

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public String getApplyCode() {
        return applyCode;
    }

    public void setApplyCode(String applyCode) {
        this.applyCode = applyCode;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public List<ExitSupplierEntity> getExitSupplierList() {
        return exitSupplierList;
    }

    public void setExitSupplierList(List<ExitSupplierEntity> exitSupplierList) {
        this.exitSupplierList = exitSupplierList;
    }
}

==> cscec5b-rmat-impl-3.0.1-20240124.105445-281-sources.jar: com/ejianc/business/rmat/bean/ExitEntity.java <==
package com.ejianc.business.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退场单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_exit")
public class ExitEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_source_id")
    private String projectSourceId; // 项目来源ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_source_id")
    private String orgSourceId; // 组织来源ID
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 上级组织
    @TableField(value="parent_org_source_id")
    private String parentOrgSourceId; // 上级组织来源ID
    @TableField(value="contract_id")
    private String contractId; // 合同主键
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="supplier_id")
    private Long supplierId; // 设备供应商
    @TableField(value="supplier_name")
    private String supplierName; // 供应商名称
    @TableField(value="supplier_source_id")
    private String supplierSourceId; // 供应商来源ID
    @TableField(value="exit_date")
    private Date exitDate; // 退场日期
    @TableField(value="confirm_date")
    private Date confirmDate; // 确认日期
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="confirm_flag")
    private Integer confirmFlag; // 确认状态0-未确认1-已确认2-已拒绝
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="confirmer_id")
    private Long confirmerId; // 确认人
    @TableField(value="confirmer_name")
    private String confirmerName; // 确认人名称
    @TableField(value="exit_note")
    private String exitNote; // 退场说明
    @TableField(value="confirm_note")
    private String confirmNote; // 确认说明
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="def1")
    private String def1; // 
    @TableField(value="def2")
    private String def2; // 
    @TableField(value="def3")
    private String def3; // 
    @TableField(value="def4")
    private String def4; // 
    @TableField(value="def5")
    private String def5; // 
    @TableField(value="apply_id")
    private Long applyId; // 申请单ID
    @TableField(value="save_state")
    private Integer saveState; // 保存状态（0-暂存态，1-保存态）
    @TableField(value="use_state")
    private Integer useState; // 推送NC状态，0-未推送，1-已推送
    @TableField(value="push_user_id")
    private Long pushUserId; // 推送人主键
    @TableField(value="push_user_source_id")
    private String pushUserSourceId; // 推送人来源ID
    @TableField(value="push_user_name")
    private String pushUserName; // 推送人名称
    @TableField(value="isaddrecord")
    private String isaddrecord; // 是否补录，0-否，1-是
    @TableField(value="addrcdreson")
    private String addrcdreson; // 补录原因
    @TableField(value="commit_id")
    private Long commitId; // 提交人
    @TableField(value="link_id")
    private Long linkId; // 联系人
    @TableField(value="link_name")
    private String linkName; // 联系人名称
    @TableField(value="link_telephone")
    private String linkTelephone; // 联系人电话
    @TableField(value="apply_date")
    private Date applyDate; // 申请日期
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="apply_code")
    private String applyCode;//申请单编号
    @TableField(value="check_name")
    private java.lang.String checkName; //
    @TableField(value="license_plate")
    private java.lang.String licensePlate; // 车牌号
    @TableField(value="materialnumber")
    private java.lang.String materialnumber; // 原始单号
    @TableField(value="construction")
    private java.lang.String construction; // 退场部位
    @TableField(value="print_num")
    private java.lang.Integer printNum; // 打印次数
    @TableField(exist=false)
    @SubEntity(serviceName="exitDetailService",pidName = "exitId")
    private List<ExitDetailEntity> exitDetail = new ArrayList<>(); // 退场单明细
    @TableField(exist=false)
    private List<ExitSupplierEntity> exitSupplierList = new ArrayList<>();//退场劳务队明细

    public Integer getPrintNum() {
        return printNum;
    }

    public void setPrintNum(Integer printNum) {
        this.printNum = printNum;
    }

    public String getCheckName() {
        return checkName;
    }

    public void setCheckName(String checkName) {
        this.checkName = checkName;
    }

    public String getLicensePlate() {
        return licensePlate;
    }

    public void setLicensePlate(String licensePlate) {
        this.licensePlate = licensePlate;
    }

    public String getMaterialnumber() {
        return materialnumber;
    }

    public void setMaterialnumber(String materialnumber) {
        this.materialnumber = materialnumber;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgSourceId() {
        return parentOrgSourceId;
    }

    public void setParentOrgSourceId(String parentOrgSourceId) {
        this.parentOrgSourceId = parentOrgSourceId;
    }
    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierSourceId() {
        return supplierSourceId;
    }

    public void setSupplierSourceId(String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }
    public Date getExitDate() {
        return exitDate;
    }

    public void setExitDate(Date exitDate) {
        this.exitDate = exitDate;
    }
    public Date getConfirmDate() {
        return confirmDate;
    }

    public void setConfirmDate(Date confirmDate) {
        this.confirmDate = confirmDate;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Integer getConfirmFlag() {
        return confirmFlag;
    }

    public void setConfirmFlag(Integer confirmFlag) {
        this.confirmFlag = confirmFlag;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getConfirmerId() {
        return confirmerId;
    }

    public void setConfirmerId(Long confirmerId) {
        this.confirmerId = confirmerId;
    }
    public String getConfirmerName() {
        return confirmerName;
    }

    public void setConfirmerName(String confirmerName) {
        this.confirmerName = confirmerName;
    }
    public String getExitNote() {
        return exitNote;
    }

    public void setExitNote(String exitNote) {
        this.exitNote = exitNote;
    }
    public String getConfirmNote() {
        return confirmNote;
    }

    public void setConfirmNote(String confirmNote) {
        this.confirmNote = confirmNote;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }
    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }
    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }
    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }
    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }
    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public Integer getSaveState() {
        return saveState;
    }

    public void setSaveState(Integer saveState) {
        this.saveState = saveState;
    }
    public Integer getUseState() {
        return useState;
    }

    public void setUseState(Integer useState) {
        this.useState = useState;
    }
    public Long getPushUserId() {
        return pushUserId;
    }

    public void setPushUserId(Long pushUserId) {
        this.pushUserId = pushUserId;
    }
    public String getPushUserSourceId() {
        return pushUserSourceId;
    }

    public void setPushUserSourceId(String pushUserSourceId) {
        this.pushUserSourceId = pushUserSourceId;
    }
    public String getPushUserName() {
        return pushUserName;
    }

    public void setPushUserName(String pushUserName) {
        this.pushUserName = pushUserName;
    }
    public String getIsaddrecord() {
        return isaddrecord;
    }

    public void setIsaddrecord(String isaddrecord) {
        this.isaddrecord = isaddrecord;
    }
    public String getAddrcdreson() {
        return addrcdreson;
    }

    public void setAddrcdreson(String addrcdreson) {
        this.addrcdreson = addrcdreson;
    }
    public Long getCommitId() {
        return commitId;
    }

    public void setCommitId(Long commitId) {
        this.commitId = commitId;
    }
    public Long getLinkId() {
        return linkId;
    }

    public void setLinkId(Long linkId) {
        this.linkId = linkId;
    }
    public String getLinkName() {
        return linkName;
    }

    public void setLinkName(String linkName) {
        this.linkName = linkName;
    }
    public String getLinkTelephone() {
        return linkTelephone;
    }

    public void setLinkTelephone(String linkTelephone) {
        this.linkTelephone = linkTelephone;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }

    public List<ExitDetailEntity> getExitDetail() {
        return exitDetail;
    }

    public void setExitDetail(List<ExitDetailEntity> exitDetail) {
        this.exitDetail = exitDetail;
    }

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public String getApplyCode() {
        return applyCode;
    }

    public void setApplyCode(String applyCode) {
        this.applyCode = applyCode;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public List<ExitSupplierEntity> getExitSupplierList() {
        return exitSupplierList;
    }

    public void setExitSupplierList(List<ExitSupplierEntity> exitSupplierList) {
        this.exitSupplierList = exitSupplierList;
    }
}
